@@ -8,9 +8,9 @@ source ~/venv/bin/activate
 pip install fava --upgrade
 
 rm -f ~/example.beancount ~/budgets-example.beancount ~/huge-example.beancount
-curl -o ~/example.beancount https://raw.githubusercontent.com/beancount/fava/master/contrib/examples/example.beancount
-curl -o ~/budgets-example.beancount https://raw.githubusercontent.com/beancount/fava/master/contrib/examples/budgets-example.beancount
-curl -o ~/huge-example.beancount https://raw.githubusercontent.com/beancount/fava/master/contrib/examples/huge-example.beancount
+curl -o ~/example.beancount https://raw.githubusercontent.com/beancount/fava/main/contrib/examples/example.beancount
+curl -o ~/budgets-example.beancount https://raw.githubusercontent.com/beancount/fava/main/contrib/examples/budgets-example.beancount
+curl -o ~/huge-example.beancount https://raw.githubusercontent.com/beancount/fava/main/contrib/examples/huge-example.beancount
 
 chmod 400 ~/example.beancount
 chmod 400 ~/budgets-example.beancount
