@@ -1,19 +1,17 @@
-import { baseURL, urlSyncedParams } from "./stores/url";
+import { get } from "svelte/store";
 
-let baseURL_val = "";
-baseURL.subscribe((val) => {
-  baseURL_val = val;
-});
+import { baseURL } from "./stores";
+import { urlSyncedParams } from "./stores/url";
 
 /**
  * Get the URL string for one of Fava's reports.
  */
 export function urlFor(
   report: string,
-  params?: Record<string, string>,
+  params?: Record<string, string | number | undefined>,
   update = true
 ): string {
-  const url = `${baseURL_val}${report}`;
+  const url = `${get(baseURL)}${report}`;
   const urlParams = new URLSearchParams();
   if (update) {
     const oldParams = new URL(window.location.href).searchParams;
@@ -26,14 +24,11 @@ export function urlFor(
   }
   if (params) {
     Object.entries(params).forEach(([key, value]) => {
-      urlParams.set(key, value);
+      if (value !== undefined) {
+        urlParams.set(key, `${value}`);
+      }
     });
   }
   const urlParamString = urlParams.toString();
   return urlParamString ? `${url}?${urlParams.toString()}` : url;
 }
-
-/** Url for the account page for an account. */
-export function accountUrl(account: string): string {
-  return new URL(urlFor(`account/${account}`), window.location.href).toString();
-}
