@@ -1,7 +1,9 @@
-import { derived, Readable, Writable, writable } from "svelte/store";
+import type { Readable, Writable } from "svelte/store";
+import { derived, writable } from "svelte/store";
 
 import { shallow_equal } from "./equals";
-import { Validator } from "./validation";
+import { parseJSON } from "./json";
+import type { Validator } from "./validation";
 
 /**
  * Create a derived store that does a shallow array equality check.
@@ -38,13 +40,20 @@ export function localStorageSyncedStore<T>(
   validator: Validator<T>,
   init: () => T
 ): Writable<T> {
-  const stored_val = localStorage.getItem(key);
-  const initial = stored_val ? validator(JSON.parse(stored_val)) : init();
-
-  const store = writable(initial);
+  const fullKey = `fava-${key}`;
+  const stored_val = localStorage.getItem(fullKey);
+  let initial: T | null = null;
+  if (stored_val) {
+    const json = parseJSON(stored_val);
+    const parsed = json.success ? validator(json.value) : null;
+    if (parsed?.success) {
+      initial = parsed.value;
+    }
+  }
+  const store = writable(initial ?? init());
 
   store.subscribe((val) => {
-    localStorage.setItem(key, JSON.stringify(val));
+    localStorage.setItem(fullKey, JSON.stringify(val));
   });
   return store;
 }
