@@ -1,8 +1,9 @@
-import test from "ava";
+import { test } from "uvu";
+import assert from "uvu/assert";
 
 import { Events } from "../src/lib/events";
 
-test("register and listen to events", (t) => {
+test("register and listen to events", () => {
   const e = new Events<"t">();
   let count = 0;
   let once = 0;
@@ -13,14 +14,16 @@ test("register and listen to events", (t) => {
   e.once("t", () => {
     once += 1;
   });
-  t.is(count, 0);
-  t.is(once, 0);
+  assert.is(count, 0);
+  assert.is(once, 0);
   e.trigger("t");
   e.trigger("t");
   e.trigger("t");
-  t.is(count, 3);
-  t.is(once, 1);
+  assert.is(count, 3);
+  assert.is(once, 1);
   e.remove("t", inc);
   e.trigger("t");
-  t.is(count, 3);
+  assert.is(count, 3);
 });
+
+test.run();
