@@ -1,10 +1,10 @@
 # pylint: disable=missing-docstring
-
 import datetime
 
 from beancount.loader import load_string
 
-from fava.core.misc import sidebar_links, upcoming_events
+from fava.core.misc import sidebar_links
+from fava.core.misc import upcoming_events
 
 
 def test_sidebar_links(load_doc):
@@ -18,7 +18,7 @@ def test_sidebar_links(load_doc):
 
 def test_upcoming_events():
     entries, _, _ = load_string(
-        '{} event "some_event" "test"\n'
-        '2012-12-12 event "test" "test"'.format(str(datetime.date.today()))
+        f'{datetime.date.today()} event "some_event" "test"\n'
+        '2012-12-12 event "test" "test"'
     )
     assert len(upcoming_events(entries, 1)) == 1
