@@ -1,6 +1,5 @@
 # pylint: disable=missing-docstring
-
-import os
+from pathlib import Path
 
 from fava.ext import find_extensions
 
@@ -16,14 +15,14 @@ def test_find_extensions():
     assert len(errors) == 1
     assert errors[0].message == 'Module "fava" contains no extensions.'
 
-    path = os.path.join(os.path.dirname(__file__), "../fava/ext")
-    classes, errors = find_extensions(path, "auto_commit")
+    path = Path(__file__).parent.parent / "src" / "fava" / "ext"
+    classes, errors = find_extensions(str(path), "auto_commit")
     assert len(classes) == 1
     assert classes[0].__name__ == "AutoCommit"
     assert errors == []
 
-    path = os.path.join(os.path.dirname(__file__), "../fava/ext")
-    classes, errors = find_extensions(path, "portfolio_list")
+    path = Path(__file__).parent.parent / "src" / "fava" / "ext"
+    classes, errors = find_extensions(str(path), "portfolio_list")
     assert len(classes) == 1
     assert classes[0].__name__ == "PortfolioList"
     assert errors == []
